@@ -1,12 +1,32 @@
 #!/usr/bin/env python3
 """
-BioQL v4.0.0: Enterprise Quantum Computing for Bioinformatics
+BioQL v5.0.1: Enterprise Quantum Computing with Full QEC Control
 
 BioQL is a quantum computing framework specifically designed for bioinformatics
 applications. It provides a natural language interface for quantum programming
 and integrates with popular quantum computing backends.
 
-🚀 NEW in v4.0.0 - ENTERPRISE EDITION:
+🆕 NEW in v5.0.1 - AWS BRAKET EXAMPLES:
+- **AWS Braket Setup Scripts**: Complete automated setup for Amazon Braket
+- **Example Circuits**: Bell state, GHZ, and more in OpenQASM 3.0
+- **Integration Guides**: Step-by-step AWS Braket + BioQL integration
+- **Verified Results**: 100% quantum entanglement confirmed on SV1
+
+🚀 FEATURES from v5.0.0 - FULL QEC CONTROL EDITION:
+- **Full Qubit Management**: Control physical vs logical qubits explicitly
+- **Advanced QEC Codes**: Surface Code, Steane Code, Shor Code implementations
+- **Qualtran Visualization**: Resource estimation and QEC overhead graphs
+- **Error Mitigation**: ZNE, PEC, readout calibration, symmetry verification
+- **QEC Metrics**: Comprehensive fidelity and error rate tracking
+- **Dynamic Pricing**: QEC overhead cost calculation with multipliers
+- **Target Fidelity**: Set minimum fidelity requirements (95-99.9%)
+
+Previous features (v4.1.0):
+- Quantum Error Correction (QEC) Module - Target 95-100% accuracy
+  * OpenFermion: Molecular Hamiltonians (H2, LiH, H2O, N2, BeH2)
+  * Qualtran: QEC gates cost analysis, RSA ModExp factorization
+  * Advanced error mitigation: ZNE, PEC, readout correction, symmetry
+- Multi-backend support: IBM Torino (133 qubits), IonQ, AWS Braket
 - Error mitigation strategies (readout error, ZNE, PEC)
 - Provenance & compliance logging (21 CFR Part 11 aligned)
 - Cryptographic audit trails with signed records
@@ -57,11 +77,28 @@ Basic Usage:
     >>> from bioql.circuits import VQECircuit, get_catalog
     >>> vqe = VQECircuit(hamiltonian="H2")
     >>> circuit = vqe.build(num_qubits=4, num_layers=2)
+
+QEC Module Usage (NEW in v4.0.0):
+    >>> from bioql import quick_chemistry_test, quick_qec_demo, demo_error_mitigation
+    >>>
+    >>> # OpenFermion: Quantum chemistry
+    >>> h2 = quick_chemistry_test('H2')
+    >>> print(f"Energy: {h2.energy_ground_state:.4f} Hartrees")
+    >>> print(f"Accuracy: {h2.accuracy_percent:.1f}%")
+    >>>
+    >>> # Qualtran: QEC analysis & RSA ModExp
+    >>> qec_result, rsa_result = quick_qec_demo()
+    >>> print(f"Qubits: {qec_result.num_logical_qubits} → {qec_result.num_physical_qubits}")
+    >>> print(f"RSA factorization cost: {rsa_result.qec_gates_cost}")
+    >>>
+    >>> # Advanced error mitigation
+    >>> em = demo_error_mitigation()
+    >>> print(f"Accuracy: {em.accuracy_original:.1f}% → {em.accuracy_mitigated:.1f}%")
 """
 
-__version__ = "4.0.0"
-__author__ = "BioQL Development Team"
-__email__ = "bioql@example.com"
+__version__ = "5.1.5"
+__author__ = "BioQL Development Team / SpectrixRD"
+__email__ = "bioql@spectrixrd.com"
 __license__ = "MIT"
 
 # Core imports
@@ -147,6 +184,69 @@ except ImportError:
     quick_benchmark = None
     LITERATURE_DATA = None
 
+# NEW in v4.0.0 - Quantum Error Correction (QEC) Module
+try:
+    from .chemistry_qec import (
+        QuantumChemistry,
+        MoleculeResult,
+        quick_chemistry_test
+    )
+except ImportError:
+    QuantumChemistry = None
+    MoleculeResult = None
+    quick_chemistry_test = None
+
+try:
+    from .qualtran_qec import (
+        QuantumErrorCorrection,
+        QECAnalysisResult,
+        RSAModExpResult,
+        quick_qec_demo
+    )
+except ImportError:
+    QuantumErrorCorrection = None
+    QECAnalysisResult = None
+    RSAModExpResult = None
+    quick_qec_demo = None
+
+try:
+    from .advanced_qec import (
+        AdvancedErrorMitigation,
+        ErrorMitigationResult,
+        demo_error_mitigation
+    )
+except ImportError:
+    AdvancedErrorMitigation = None
+    ErrorMitigationResult = None
+    demo_error_mitigation = None
+
+# NEW in v5.0.0 - Full QEC Control & Visualization
+try:
+    from .qec import (
+        SurfaceCodeQEC,
+        SteaneCodeQEC,
+        ShorCodeQEC,
+        ErrorMitigation,
+        QECMetrics
+    )
+except ImportError:
+    SurfaceCodeQEC = None
+    SteaneCodeQEC = None
+    ShorCodeQEC = None
+    ErrorMitigation = None
+    QECMetrics = None
+
+try:
+    from .visualization import (
+        QECVisualizer,
+        ResourceEstimator,
+        ResourceEstimation
+    )
+except ImportError:
+    QECVisualizer = None
+    ResourceEstimator = None
+    ResourceEstimation = None
+
 # Define what gets exported when using "from bioql import *"
 __all__ = [
     # Core functionality
@@ -198,6 +298,23 @@ if ChemistryBenchmark is not None:
         "quick_benchmark", "LITERATURE_DATA"
     ])
 
+# Add QEC modules if available
+if QuantumChemistry is not None:
+    __all__.extend([
+        "QuantumChemistry", "MoleculeResult", "quick_chemistry_test"
+    ])
+
+if QuantumErrorCorrection is not None:
+    __all__.extend([
+        "QuantumErrorCorrection", "QECAnalysisResult", "RSAModExpResult",
+        "quick_qec_demo"
+    ])
+
+if AdvancedErrorMitigation is not None:
+    __all__.extend([
+        "AdvancedErrorMitigation", "ErrorMitigationResult", "demo_error_mitigation"
+    ])
+
 
 def get_version() -> str:
     """Return the current version of BioQL."""
